Struct LeapSecond
#[repr(C)]pub struct LeapSecond {
pub timestamp_tai_s: f64,
pub delta_at: f64,
pub announced_by_iers: bool,
}Expand description
A structure representing a leap second
Fields
timestamp_tai_s: f64Timestamp in TAI seconds for this leap second, e.g. 2_272_060_800.0 for the first IERS leap second.
delta_at: f64ΔAT is the accumulated time offset after this leap second has past.
announced_by_iers: boolWhether or not this leap second was announced by the IERS.
Implementations
impl LeapSecond
impl LeapSecond
pub const fn new( timestamp_tai_s: f64, delta_at: f64, announced: bool, ) -> LeapSecond